package easik.database.types;

import java.sql.Types;
import java.sql.PreparedStatement;
import java.sql.SQLException;

/**
 * A class representing a FLOAT (also known as REAL) SQL data type.  A FLOAT
 * typically has a range of about 1e-37 to 1e+37, and a precision of at least 6
 * digits.  See also DOUBLE PRECISION, for more precise floating point numbers,
 * and DECIMAL for fixed-precision floating point values.  In standard SQL, this
 * is essentially a FLOAT(24).
 */
public class Float extends Type {
	public String toString() { return "FLOAT"; }

	public boolean verifyInput(String input){
		return input.matches("^([+−]?)(?=\\d|\\.\\d)\\d*(\\.\\d*)?([Ee]([+−]?\\d+))?$");
	}

	public int getSqlType(){ return Types.FLOAT; }

	public void bindValue(PreparedStatement ps, int col, String value) throws SQLException{
		ps.setFloat(col, java.lang.Float.parseFloat(value));
	}
}
