package easik.database.types;

import java.sql.Types;
import java.sql.PreparedStatement;
import java.sql.SQLException;

/**
 * A class representing a SMALLINT SQL data type.  A SMALLINT can contain values
 * from -2^15 to 2^15-1.  Some databases may not support SMALLINT and may be
 * automatically converted to an INTEGER instead.  See also Integer and BigInt.
 */
public class SmallInt extends Type {
	public String toString() { return "SMALLINT"; }

	public boolean verifyInput(String input){
		return input.matches("^[-+]?\\d{1,5}$");
	}

	public int getSqlType(){ return Types.SMALLINT; }

	public void bindValue(PreparedStatement ps, int col, String value) throws SQLException{
		ps.setInt(col, Integer.parseInt(value));
	}
}
