package easik.database.types;

import java.sql.Types;
import java.sql.PreparedStatement;
import java.sql.SQLException;

/**
 * A class representing a TIMESTAMP SQL data type.  A TIMESTAMP value stores a
 * date and time (such as '2008-06-12 18:58:32').  Note that, some databases
 * (MySQL in particular) have a bizarre and standard-incompatible version of
 * TIMESTAMP, but have the alternative DATETIME type that will be used instead.
 * See TimestampWithTimeZone for an alternative that includes a timezone with
 * the date/time.
 */
public class Timestamp extends Type {
	public String toString() { return "TIMESTAMP"; }

	public boolean verifyInput(String input){
		return true;
	}

	public int getSqlType(){ return Types.TIMESTAMP; }

	public void bindValue(PreparedStatement ps, int col, String value) throws SQLException{
		ps.setTimestamp(col, new java.sql.Timestamp(Long.parseLong(value)));
	}
}
