package easik.database.types;

import java.util.Map;
import java.util.Collections;
import java.sql.Types;
import java.sql.PreparedStatement;
import java.sql.SQLException;

/**
 * A class representing a VARCHAR(n) SQL data type.
 */
public class Varchar extends Type {
	private int size;
	/**
	 * Creates a new Varchar object.  The n specifies the required size of this
	 * varchar.  Note that some databases may not support size values larger
	 * than 255.
	 */
	public Varchar(int n) {
		size = n;
	}

	public int getSize() {
		return size;
	}
	public String toString() { return "VARCHAR("+size+")"; }

	public boolean verifyInput(String input){
		return input.matches("^.{0," + size + "}$");
	}

	/**
	 * Returns the attributes of this object
	 */
	public Map<String, String> attributes() {
		return Collections.singletonMap("size", size+"");
	}
	/**
	 * Recreates the object from the attributes returned by attributes().
	 */
	public Varchar(Map<String, String> attr) {
		this(Integer.parseInt(attr.get("size")));
	}

	public int getSqlType(){ return Types.VARCHAR; }

	public void bindValue(PreparedStatement ps, int col, String value) throws SQLException{
		ps.setString(col, value);
	}
}
