package easik.sketch.edge;

import easik.sketch.vertex.EntityNode;

/**
 * A subclass of SketchEdge that identifies an edge as an injective edge.
 * @see SketchEdge
 */
public class InjectiveEdge extends SketchEdge {
	/**
	 * Creates a new injective edge between two entity nodes with the specified
	 * name and RESTRICT cascading.
	 *
	 * @param source The source entity node
	 * @param source The target entity node
	 * @param name The unique edge identifier
	 * @see SketchEdge(EntityNode, EntityNode, String)
	 * @see PartialEdge(EntityNode, EntityNode, String)
	 */
	public InjectiveEdge(EntityNode a, EntityNode b, String name) {
		this(a, b, name, Cascade.RESTRICT);
	}

	/**
	 * Creates a new injective edge between two entity nodes with the specified
	 * name and cascading option.
	 *
	 * @param source The source entity node
	 * @param source The target entity node
	 * @param name The unique edge identifier
	 * @param cascade The cascade value, such as SketchEdge.Cascade.RESTRICT
	 * @see SketchEdge.Cascade
	 * @see SketchEdge(EntityNode, EntityNode, String)
	 * @see PartialEdge(EntityNode, EntityNode, String)
	 */
	public InjectiveEdge(EntityNode a, EntityNode b, String name, Cascade cascade) {
		super(a, b, name, cascade);
	}

	public boolean isInjective() {
		return true;
	}
}
