package easik.sketch.states;




import easik.sketch.Sketch;
import easik.sketch.edge.*;
import easik.sketch.constraint.Constraint;

/**
 *	The basic editing state is the lowest state of the state manager. It can not be popped
 *	off. Basic editing allows access to the basic tools of building sketches.
 *
 *	@author Rob Fletcher 2005
 *	@author Kevin Green 2006
 *	@version 2006-07-13 Kevin Green
 */

public class BasicEditingState extends SketchState {

	public BasicEditingState(Sketch inSketch){
		super(inSketch);
	}


	/**
	 * There is nowhere to go from basic editing (state-wise) so when it is pushed
	 * on, it disables Next and Cancel.
	 */
	public void pushedOn() {
		this.setCancelButton(false);
		this.setNextButton(false);		
	}

	/**
	 * Empty method, as this should never be popped off. 
	 */
	public void poppedOff() {		
	}

	/**
	 * When we're in basic editing state, we want to be able to add constraints.
	 */
	 public void gotFocus() {
		_ourSketch.getFrame().enableAddConstraintItems(true);
	 }
	
	/**
	 * Used to identify this class.
	 * 
	 * @return String literal "Basic Editing"
	 */
	public String toString() {
		return "Basic Editing";
	}
	
	/**
	 * Update the selection so that the only selectable items will be those within
	 * reach of the existing edges.
	 */
	public void selectionUpdated() {
		setNextButton(false);
		setFinishButton(false);

		_ourSketch.getGraphLayoutCache().reload();
	}
}
