package easik.ui.menu;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import javax.imageio.ImageIO;
import java.util.regex.*;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;

import easik.*;
import easik.sketch.Sketch;
import easik.ui.FileChooser;
import easik.ui.SketchFrame;
import easik.ui.FileChooser;
import easik.ui.FileFilter;


/**
 * Menu action to export the current sketch as an image.
 */
public class ExportImageAction extends AbstractAction{

	Sketch _theSketch;

	/**
	 * Creates a new ExportImageAction.  Adds a new menu option to the File menu.
	 */
	public ExportImageAction(SketchFrame inFrame){
		super(inFrame instanceof SketchFrame ? "Image..." : "Export to image...");
		_theSketch = inFrame.getSketch();
		putValue(AbstractAction.MNEMONIC_KEY, new Integer(KeyEvent.VK_I));
		putValue(AbstractAction.SHORT_DESCRIPTION, "Export an image of the current sketch.");
	}

	/**
	 * Creates a new image of the current sketch and prompts the user for a place to
	 * save it.  Displays a message if an error occurred.
	 *
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e) {
		String error;
		if (_theSketch.getEntities().isEmpty()) {
			showError("Unable to export: the sketch is empty!", "Error");
			return;
		}

		FileFilter imageFilter = new FileFilter("Image files (*.png; *.jpg; *.gif; *.bmp)", "png", "jpg", "jpeg", "gif", "bmp");
		File selFile = FileChooser.saveFile("Export image", imageFilter, "png");

		if (selFile == null) return; // Cancelled

		java.awt.Color background = Easik.getInstance().getSettings().getColor("edit_canvas_background");
		BufferedImage snapshot = _theSketch.getImage(background, 5);
		if (snapshot == null) {
			showError("Unable to export: failed to obtain a snapshot of the sketch!", "Error");
			return;
		}

		String format = "png";
		Pattern suffix = Pattern.compile("\\.(?i:(png|bmp|jpg|jpeg|gif))$");
		Matcher m = suffix.matcher(selFile.getName());
		if (m.find()) {
			format = m.group(1).toLowerCase();
		}

		try {
			ImageIO.write(snapshot, format, selFile);
		}
		catch (IOException ioe) {
			showError("Exporting image failed: " + ioe.getMessage(), "Error");
			return;
		}

		JOptionPane.showMessageDialog(_theSketch.getFrame(),
				"Created " + selFile.getName() + " successfully", "Image Exported",
				JOptionPane.INFORMATION_MESSAGE);
	}

	private void showError(String message, String title) {
		JOptionPane.showMessageDialog(_theSketch.getFrame(), message, title, JOptionPane.ERROR_MESSAGE);
	}
}
