package easik.ui.menu;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;
import java.io.File;

import javax.swing.AbstractAction;

import easik.*;
import easik.ui.*;
import easik.ui.FileFilter;
import easik.ui.FileChooser;
import easik.overview.Overview;


/** 
 * Menu action for exporting the overview as XML
 * @author Rob Fletcher 2005
 * @author Kevin Green 2006
 * @version 2006-07-13 Kevin Green
 */

public class FileSaveAsAction extends AbstractAction {

	/**
	 * The frame containing the overview that will be saved
	 */
	ApplicationFrame _theFrame;

	/**
	 * Create a new save as menu action.
	 */
	public FileSaveAsAction(ApplicationFrame inFrame) {
		super("Save Overview As...");
		_theFrame = inFrame;
		putValue(AbstractAction.MNEMONIC_KEY, new Integer(KeyEvent.VK_A));
		putValue(
			AbstractAction.SHORT_DESCRIPTION,
			"Export current overview as XML document");		
	}

	/**
	 * Display a dialog prompting the user for the name under which to save the current overview.
	 *  
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e) {
		saveFileAs(_theFrame);
	}

	/**
	 * Prompts for a filename and saves the overview as that name.  Returns true
	 * if the file was successfully saved, false if not (i.e. because the user
	 * cancelled).
	 */
	public static boolean saveFileAs(ApplicationFrame inFrame){
		Overview overview = inFrame.getOverview();
		File selFile = FileChooser.saveFile("Save EASIK Sketch", FileFilter.EASIK, "easik");

		if (selFile != null)
			return FileSaveAction.saveFile(inFrame, selFile);

		return false;
	}
}
