package easik.ui.menu;

import easik.graph.EasikGraphModel;
import easik.sketch.Sketch;
import easik.view.View;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;

import javax.swing.AbstractAction;

import org.jgraph.JGraph;

/**
 * Menu action for undoing the last edit.
 */
public class UndoAction extends AbstractAction {
	private JGraph graph;

	public UndoAction(Sketch sketch) {
		this((JGraph) sketch);

		putValue(AbstractAction.SHORT_DESCRIPTION, "Undo the last change made to the sketch");
	}

	public UndoAction(View view) {
		this((JGraph) view);

		putValue(AbstractAction.SHORT_DESCRIPTION, "Undo the last change made to the view");
	}

	private UndoAction(JGraph graph) {
		super("Undo");
		this.graph = graph;
		putValue(AbstractAction.MNEMONIC_KEY, KeyEvent.VK_U);
	}

	/**
	 * When action is performed, do an undo.
	 * 
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e) {
		EasikGraphModel model = (EasikGraphModel) graph.getModel();
		if (model.canUndo()) {
			model.undo();
		}
	}
}
