package easik.ui.menu.popup;

import java.awt.event.ActionEvent;

import java.util.*;
import java.sql.*;

import javax.swing.AbstractAction;

import easik.database.DatabaseDriver;
import easik.database.types.*;
import easik.sketch.Sketch;
import easik.sketch.vertex.EntityNode;
import easik.ui.datamanip.*;

/**
 * Action for adding a row to a table in the popup menu
 */
public class AddRowAction extends AbstractAction {
	/** The sketch in which any table we wish to add data exists. */
	private Sketch _theSketch;

	/**
	 * Prepare the menu option.
	 * 
	 * @param inSketch The sketch in which any table we wish to add to exists.
	 */
	public AddRowAction(Sketch inSketch) {
		super("Add row to table...");
		_theSketch = inSketch;
		putValue(
			AbstractAction.SHORT_DESCRIPTION,
			"Add a row into selected table");
	}

	/**
	 * Checks that our sketch has a database driver, and sends the selected entity node off to the sketch's update monitor.
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e) {
		Object[] currentSelection = _theSketch.getSelectionCells();
		if( !(currentSelection[0] instanceof EntityNode) || ! _theSketch.hasDatabaseDriver()){
			return;
		}

		UpdateMonitor um = _theSketch.getUpdateMonitor();
		um.insert((EntityNode)currentSelection[0]);
	}
}
