package easik.ui.menu.popup;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;

import easik.ui.SketchFrame;
import easik.sketch.Sketch;
import easik.sketch.edge.SketchEdge;

/**
 * Action for editing (renaming and setting cascade mode) a sketch edge.
 */
public class EditSketchEdgeAction extends AbstractAction {

	private SketchFrame _theFrame;

	/**
	 * Sets up rename action
	 */
	public EditSketchEdgeAction(SketchFrame inFrame) {		
		super("Edit edge ...");
		_theFrame = inFrame;
		putValue(AbstractAction.MNEMONIC_KEY, new Integer(KeyEvent.VK_R));
		putValue(
				AbstractAction.SHORT_DESCRIPTION,
				"Edit the name and cascade option of the selected edge");
	}

	/**
	 * Called when clicked upon, will popup the edge UI and, if accepted,
	 * update the name and cascade option.
	 * 
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e ) {
		Sketch _ourSketch = _theFrame.getSketch();

		Object[] currentSelection = _ourSketch.getSelectionCells();

		// If only one edge is selected, then we allow this. We will ignore any
		// non-edges which might be selected
		if (currentSelection.length == 1 && currentSelection[0] instanceof SketchEdge) {
			// If we're currently synced with a database, give the user the chance to cancel operation
			if(_ourSketch.isSynced()){
				if(JOptionPane.showConfirmDialog(_theFrame, 
							"Warning: this sketch is currently synced with a database; delete and break synchronization?", 
							"Warning!", 
							JOptionPane.OK_CANCEL_OPTION,
							JOptionPane.WARNING_MESSAGE) == JOptionPane.CANCEL_OPTION){
					return;
				}
			}

			SketchEdge edge = (SketchEdge) currentSelection[0];

			EdgeOptions opts = new EdgeOptions(_theFrame, edge);
			if (opts.isAccepted()) {
				if (!opts.getName().equals(edge.getName()))
					edge.setName(opts.getName());
				edge.setCascading(opts.getCascadeMode());

				_theFrame.getInfoTreeUI().refreshTree();
				_ourSketch.getGraphLayoutCache().reload();

				_ourSketch.clearSelection();

				_ourSketch.repaint();
				_ourSketch.setDirty();
				_ourSketch.setSynced(false);
			}
		}	
	}
}
