package easik.ui.menu.popup;

import java.awt.event.ActionEvent;

import java.util.*;
import java.sql.*;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;

import easik.database.DatabaseDriver;
import easik.database.types.*;
import easik.sketch.Sketch;
import easik.sketch.vertex.EntityNode;
import easik.ui.datamanip.*;

/**
 * Action for executing a free-form SQL delete query on a selected table. Sets some default
 * text to minimize typing required by user.
 */
public class ExecPreparedDeleteAction extends AbstractAction {
	/** The sketch which contains the valid tables we can query */
	private Sketch _theSketch;

	/**
	 * Sets up action for executing a free-form query.
	 * @param inSketch The sketch which contains the valid tables to query.
	 */
	public ExecPreparedDeleteAction(Sketch inSketch) {
		super("Delete row(s) via query...");
		_theSketch = inSketch;
		putValue(
			AbstractAction.SHORT_DESCRIPTION,
			"Execute a free form DELETE query.");
	}

	/**
	 * Create the new entity and set up its name
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e) {
		Object[] currentSelection = _theSketch.getSelectionCells();
		if(! (currentSelection[0] instanceof EntityNode) ){
			return;
		}
		EntityNode table = (EntityNode)currentSelection[0];

		DatabaseDriver dbd;
		try{
			dbd = _theSketch.getDatabaseDriver();
		}
		catch(DatabaseDriver.LoadException le){
			JOptionPane.showMessageDialog(null, le.getMessage());
			return;
		}
		catch(SQLException sqle){
			JOptionPane.showMessageDialog(null, "Unable to connection to SQL server" + sqle.getMessage());
			return;
		}

		if (dbd == null) return; // The user hit Cancel

		FreeQueryDialog afqd;
		String text = "DELETE FROM " + table.getName() + "\n WHERE()";
		while(true){
			afqd = new FreeQueryDialog(_theSketch.getFrame(), dbd, text);
					

			if( ! afqd.isAccepted() ){
				return;
			}

			try{
				String input = afqd.getInput();
				dbd.executeUpdate(input);
				return;
			}
			catch(SQLException ex){
				JOptionPane.showMessageDialog(null, ex.getMessage());
				text = afqd.getInput();
				continue;
			}
		}
	}
}
