package easik.ui.menu.popup;


import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.Action;

import easik.sketch.Sketch;
import easik.overview.Overview;
import easik.overview.vertex.SketchNode;


/**
 * Action for setting the frame associated with a sketch node visible. Will be opened for data manipulation.
 */
public class OpenSketchDataAction extends AbstractAction {
	/** The overview in which the action occurs. */
	private Overview _theOverview;

	private static final String LABEL = "Manipulate database...";

	public OpenSketchDataAction(Overview inOverview){
		this(inOverview, false);
	}
	public OpenSketchDataAction(Overview inOverview, boolean bold) {
		super(bold ? "<html><b>" + LABEL + "</b></html>" : LABEL);
		_theOverview = inOverview;
		putValue(
			AbstractAction.SHORT_DESCRIPTION,
			"Open selected sketch for data manipulation.");
	}

	/**
	 * Enable editing on selected sketch.
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e) {
		Object[] selection = _theOverview.getSelectionCells();

		for (Object sel : selection) {
			if(sel instanceof SketchNode){
				((SketchNode)sel).getFrame().enableDataManip();
			}
		}

		_theOverview.clearSelection();
	}
}
