package easik.ui.tree.popup;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;

import easik.ui.SketchFrame;
import easik.sketch.attribute.EntityAttribute;
import easik.sketch.keys.UniqueKey;
import easik.sketch.keys.UniqueKeyUI;
import easik.sketch.vertex.EntityNode;


/**
 * Add unique key popup menu action for the information tree.
 * 
 * @author Kevin Green 2006
 * @since 2006-06-14 Kevin Green
 * @version 2006-07-26 Kevin Green
 */
public class AddUniqueKeyAction extends AbstractAction {

	private SketchFrame _theFrame;
	
	/**
	 *	Set up the add unqiue key menu option.
	 */
	public AddUniqueKeyAction(SketchFrame inFrame) {
		super("Add Unique Key");
		_theFrame = inFrame;
		putValue( AbstractAction.SHORT_DESCRIPTION,  "Add a unique key to the currently selected entity.");		
	}
	
	/**
	 * Inserts a unique key to the currently selected entity
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e ) {
		//If there is nothing selected then just do nothing
		if(_theFrame.getSketch().getSelectionCells().length != 1)
			return;

		// If we're currently synced with a database, give the user the chance to cancel operation
		if(_theFrame.getSketch().isSynced()){
			int choice = JOptionPane.showConfirmDialog(_theFrame, 
					"Warning: this sketch is currently synced with a database; continue and break synchronization?", 
					"Warning!", 
					JOptionPane.OK_CANCEL_OPTION,
					JOptionPane.WARNING_MESSAGE);
			if( choice == JOptionPane.CANCEL_OPTION)
				return;
		}

		//Get currently selected object
		Object curSelected = _theFrame.getSketch().getSelectionCells()[0];

		EntityNode curEntity;

		//Check what is currently selected
		if (curSelected instanceof EntityNode) {
			//Entity is selected so set it as current entity
			curEntity = (EntityNode) curSelected;
		}
		else {
			JOptionPane.showMessageDialog(_theFrame, 
					"You have not selected an entity to add the unique key to.\nPlease select an entity and try again.",
					"No entity selected", JOptionPane.ERROR_MESSAGE);
			return;
		}

		// If the entity does not contain any attributes
		if (curEntity.getEntityAttributes().isEmpty() && curEntity.getIndexableEdges().isEmpty()) {
			//Pop up error dialog
			JOptionPane.showMessageDialog(_theFrame, 
					"The selected entity has no attributes/edges.\nA unique key can only be added to an entity with\nattributes or outgoing, non-injective edges.",
					"Entity has no attributes/edges", JOptionPane.ERROR_MESSAGE);
			return;
		}

		UniqueKeyUI myUI = new UniqueKeyUI(_theFrame, curEntity);

		if (myUI.showDialog()) {
			UniqueKey newKey = new UniqueKey(curEntity, myUI.getSelectedElements(), myUI.getKeyName());

			//Create new unique key
			curEntity.addUniqueKey(newKey);

			_theFrame.getInfoTreeUI().refreshTree(curEntity); //Refresh view of entity keys

			_theFrame.getSketch().clearSelection();
			_theFrame.getSketch().setDirty();
			_theFrame.getSketch().setSynced(false);
		}
	}
}
