package easik.ui.tree.popup;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;
import javax.swing.tree.DefaultMutableTreeNode;

import easik.ui.SketchFrame;
import easik.sketch.Sketch;
import easik.sketch.constraint.Constraint;

/**
 * Action for the delete constraint option in the popup menu.
 * 
 * @author Kevin Green 2006
 * @since 2006-08-02 Kevin Green
 * @version 2006-08-02 Kevin Green
 */
public class DeleteConstraintAction extends AbstractAction{

	SketchFrame _theFrame;

	/**
	 * Sets up delete constraint action
	 */
	public DeleteConstraintAction(SketchFrame inFrame){
		super("Delete Constraint");	
		_theFrame = inFrame;
		putValue(AbstractAction.MNEMONIC_KEY, new Integer(KeyEvent.VK_D));
		putValue(AbstractAction.SHORT_DESCRIPTION, "Deletes the currently selected constraint");
	}
	
	/**
	 * Called when clicked upon, will delete constraint. 
	 * 
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e ) {
		//If there is nothing seleceted then just do nothing
		if(_theFrame.getInfoTreeUI().getInfoTree().isSelectionEmpty())
		{
			return;
		}

		// If we're currently synced with a database, give the user the chance to cancel operation
		if(_theFrame.getSketch().isSynced()){
			int choice = JOptionPane.showConfirmDialog(_theFrame, 
					"Warning: this sketch is currently synced with a database; continue and break synchronization?", 
					"Warning!", 
					JOptionPane.OK_CANCEL_OPTION,
					JOptionPane.WARNING_MESSAGE);
			if( choice == JOptionPane.CANCEL_OPTION)
				return;
		}
		
		//Get currently selected object
		DefaultMutableTreeNode curSelected = (DefaultMutableTreeNode) 
					_theFrame.getInfoTreeUI().getInfoTree().getSelectionPath().getLastPathComponent();

		if(curSelected instanceof Constraint){
			_theFrame.getSketch().removeConstraint((Constraint)curSelected);
			
			_theFrame.getSketch().setDirty();
			_theFrame.getSketch().setSynced(false);
		}
	}
}
