package easik.ui.tree.popup;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;
import javax.swing.tree.DefaultMutableTreeNode;

import easik.ui.SketchFrame;
import easik.sketch.Sketch;
import easik.sketch.vertex.EntityNode;

/**
 * Action for the delete entity option in the popup menu.
 * 
 * @author Kevin Green 2006
 * @since 2006-08-02 Kevin Green
 * @version 2006-08-02 Kevin Green
 */
public class DeleteEntityAction extends AbstractAction{
	
	SketchFrame _theFrame;

	/**
	 * Sets up delete entity action
	 */
	public DeleteEntityAction(SketchFrame inFrame){
		super("Delete Entity");	
		_theFrame = inFrame;
		putValue(AbstractAction.MNEMONIC_KEY, new Integer(KeyEvent.VK_D));
		putValue(AbstractAction.SHORT_DESCRIPTION, "Deletes the currently selected entity");
	}
	
	/**
	 * Called when clicked upon, will delete entity. 
	 * 
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e ) {
		//If there is nothing seleceted then just do nothing
		if(_theFrame.getInfoTreeUI().getInfoTree().isSelectionEmpty())
		{
			return;
		}	
		//Get Sketch object
		Sketch _ourSketch = _theFrame.getSketch();

		// If we're currently synced with a database, give the user the chance to cancel operation
		if(_ourSketch.isSynced()){
			int choice = JOptionPane.showConfirmDialog(_theFrame, 
					"Warning: this sketch is currently synced with a database; continue and break synchronization?", 
					"Warning!", 
					JOptionPane.OK_CANCEL_OPTION,
					JOptionPane.WARNING_MESSAGE);
			if( choice == JOptionPane.CANCEL_OPTION)
				return;
		}
		
		//Get currently selected object
		DefaultMutableTreeNode curSelected = (DefaultMutableTreeNode) 
					_theFrame.getInfoTreeUI().getInfoTree().getSelectionPath().getLastPathComponent();

		if(curSelected instanceof EntityNode){
			_theFrame.getSketch().removeEntity((EntityNode)curSelected);

			_theFrame.getSketch().setDirty();
			_theFrame.getSketch().setSynced(false);
		}
	}
}
