package easik.ui.tree.popup;

import java.awt.event.ActionEvent;
import java.util.ArrayList;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;
import javax.swing.tree.DefaultMutableTreeNode;

import easik.ui.SketchFrame;
import easik.sketch.constraint.*;
import easik.sketch.path.SketchPath;

/**
 * Show constraint menu action for the information tree.
 * 
 * @author Kevin Green 2006
 * @since 2006-08-17 Kevin Green
 * @version 2006-08-22 Kevin Green
 */
public class DeletePathAction extends AbstractAction {	

	SketchFrame _theFrame;

	/**
	 *	Set up the remove path menu option.
	 */
	public DeletePathAction(SketchFrame inFrame) {
		super("Remove Path from Constraint");
		_theFrame = inFrame;
		putValue( AbstractAction.SHORT_DESCRIPTION,  "Removes the currently selected path from the constraint.");		
	}
	
	/**
	 * Tests if the removal is valid and then removes the path from the constraint
	 * 
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e ) {
		//If there is nothing seleceted then just do nothing
		if(_theFrame.getInfoTreeUI().getInfoTree().isSelectionEmpty())
		{
			return;
		}

		// If we're currently synced with a database, give the user the chance to cancel operation
		if(_theFrame.getSketch().isSynced()){
			int choice = JOptionPane.showConfirmDialog(_theFrame, 
					"Warning: this sketch is currently synced with a database; continue and break synchronization?", 
					"Warning!", 
					JOptionPane.OK_CANCEL_OPTION,
					JOptionPane.WARNING_MESSAGE);
			if( choice == JOptionPane.CANCEL_OPTION)
				return;
		}
		
		//Get currently selected object
		DefaultMutableTreeNode curSelected = (DefaultMutableTreeNode) 
					_theFrame.getInfoTreeUI().getInfoTree().getSelectionPath().getLastPathComponent();

		//Selection is a constraint
		if(curSelected instanceof SketchPath){
			Constraint curConstraint = (Constraint) curSelected.getParent();
			ArrayList<SketchPath> tempPaths = new ArrayList<SketchPath>(curConstraint.getPaths());
			tempPaths.remove(curSelected);
			boolean valid = false;
			if (curConstraint instanceof SumConstraint) {
				valid = SumConstraint.isSumConstraint(tempPaths);
				// Replace previous path array list
				if (valid) ((SumConstraint) curConstraint).setPaths(tempPaths);
			}
			else if (curConstraint instanceof ProductConstraint) {
				valid = ProductConstraint.isProductConstraint(tempPaths);
				// Replace previous path array list
				if (valid) ((ProductConstraint) curConstraint).setPaths(tempPaths);
			}
			else if (curConstraint instanceof CommutativeDiagram) {
				valid = CommutativeDiagram.isCommutativeDiagram(tempPaths);
				// Replace previous path array list
				if (valid) ((CommutativeDiagram) curConstraint).setPaths(tempPaths);
			}
			else {
				JOptionPane.showMessageDialog(_theFrame,
						"You don't have a path selected that can be removed. \nPlease select another path and try again.",
						"No Constraint Selected", JOptionPane.ERROR_MESSAGE);
				return;
			}

			if (valid) {
				Constraint myConst = (Constraint) curConstraint;
				//Remove old tree node
				myConst.removeFromParent();
				_theFrame.getInfoTreeUI().addConstraint(myConst);
				//Referesh Tree
				_theFrame.getInfoTreeUI().refreshTree(myConst);
				_theFrame.getSketch().setDirty();
				_theFrame.getSketch().setSynced(false);
			}
			else {
				JOptionPane.showMessageDialog(_theFrame,
						"Revoming this path would make the constraint invalid.\nPath was not removed",
						"Path Not Removed", JOptionPane.ERROR_MESSAGE);
			}
		}
		//Selection is not a constraint
		else{ 
			JOptionPane.showMessageDialog(_theFrame,
					"You don't have a path selected. \nPlease select a path and try again.",
					"No Constraint Selected", JOptionPane.ERROR_MESSAGE);
		}
	}
}
