package easik.ui.tree.popup;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;
import javax.swing.tree.DefaultMutableTreeNode;

import easik.ui.SketchFrame;
import easik.sketch.keys.UniqueKey;
import easik.sketch.vertex.EntityNode;


/**
 * Delete unique key popup menu action for the information tree.
 * 
 * @author Kevin Green 2006
 * @since 2006-06-14 Kevin Green
 * @version 2006-07-26 Kevin Green
 */
public class DeleteUniqueKeyAction extends AbstractAction {	
	
	SketchFrame _theFrame;

	/**
	 *	Set up the add attribute menu option.
	 */
	public DeleteUniqueKeyAction(SketchFrame inFrame) {
		super("Delete Unique Key");
		_theFrame = inFrame;
		putValue( AbstractAction.SHORT_DESCRIPTION,  "Deletes the currently selected unique key.");		
	}
	
	/**
	 * Deletes the currently selected unique key
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e ) {
		//If there is nothing seleceted then just do nothing
		if(_theFrame.getInfoTreeUI().getInfoTree().isSelectionEmpty())
		{
			return;
		}

		// If we're currently synced with a database, give the user the chance to cancel operation
		if(_theFrame.getSketch().isSynced()){
			int choice = JOptionPane.showConfirmDialog(_theFrame, 
					"Warning: this sketch is currently synced with a database; continue and break synchronization?", 
					"Warning!", 
					JOptionPane.OK_CANCEL_OPTION,
					JOptionPane.WARNING_MESSAGE);
			if( choice == JOptionPane.CANCEL_OPTION)
				return;
		}
		
		//Get currently selected object
		DefaultMutableTreeNode curSelected = (DefaultMutableTreeNode) 
					_theFrame.getInfoTreeUI().getInfoTree().getSelectionPath().getLastPathComponent();

		//Selection is a unique key
		if (curSelected instanceof UniqueKey) {
			UniqueKey curKey = (UniqueKey) curSelected;
			EntityNode parentEntity = curKey.getEntity();
			
			//Show a confirmation dialog box for the deletion
			if(JOptionPane.showConfirmDialog(_theFrame,
					"Are you sure you want to delete the '" + curKey.toString() + 
					"' unique key from the '" + parentEntity + "' entity?",
					"Confirm Delete", JOptionPane.OK_CANCEL_OPTION)
					== JOptionPane.OK_OPTION){
				
				//Delete the unique key from entity
				parentEntity.removeUniqueKey(curKey);

				_theFrame.getInfoTreeUI().refreshTree(parentEntity); //Refresh view of entity

				_theFrame.getSketch().setDirty();
				_theFrame.getSketch().setSynced(false);
			}
		}
		//Selection is not an attribute
		else{ 
			JOptionPane.showMessageDialog(_theFrame,
					"You don't have a unique key selected. \nPlease select a unique key and try again.",
					"No Attribute Selected", JOptionPane.ERROR_MESSAGE);
			return;
		}
	}
}
