package easik.ui.tree.popup;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;
import javax.swing.tree.DefaultMutableTreeNode;

import easik.ui.SketchFrame;
import easik.sketch.keys.UniqueKey;
import easik.sketch.keys.UniqueKeyUI;
import easik.sketch.vertex.EntityNode;


/**
 * Edit unique key popup menu action for the information tree.
 * 
 * @author Kevin Green 2006
 * @since 2006-06-14 Kevin Green
 * @version 2006-07-26 Kevin Green
 */
public class EditUniqueKeyAction extends AbstractAction {	
	
	SketchFrame _theFrame;

	/**
	 *	Set up the edit unique key menu option.
	 */
	public EditUniqueKeyAction(SketchFrame inFrame) {
		super("Edit Unique Key");
		_theFrame = inFrame;
		putValue( AbstractAction.SHORT_DESCRIPTION,  "Edits the currently selected unique key.");		
	}
	
	/**
	 * Brings up a dialog to edit the currently selected unique key
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e ) {
		//If there is nothing seleceted then just do nothing
		if(_theFrame.getInfoTreeUI().getInfoTree().isSelectionEmpty())
			return;

		// If we're currently synced with a database, give the user the chance to cancel operation
		if(_theFrame.getSketch().isSynced()){
			int choice = JOptionPane.showConfirmDialog(_theFrame, 
					"Warning: this sketch is currently synced with a database; continue and break synchronization?", 
					"Warning!", 
					JOptionPane.OK_CANCEL_OPTION,
					JOptionPane.WARNING_MESSAGE);
			if( choice == JOptionPane.CANCEL_OPTION)
				return;
		}
		
		//Get currently selected object
		DefaultMutableTreeNode curSelected = (DefaultMutableTreeNode) 
					_theFrame.getInfoTreeUI().getInfoTree().getSelectionPath().getLastPathComponent();
		EntityNode curEntity;
		UniqueKey myKey;

		//Check what is currently selected
		if (curSelected instanceof UniqueKey) {
			//Entity is selected so set it as current entity
			myKey = (UniqueKey) curSelected;
			curEntity = myKey.getEntity();
		}
		else {
			JOptionPane.showMessageDialog(_theFrame, 
					"You do not have an entity selected. \nPlease select an entity and try again.",
					"No Entity Selected", JOptionPane.ERROR_MESSAGE);
			return;//Jump out of function
		}

		UniqueKeyUI myUI = new UniqueKeyUI(_theFrame, curEntity, myKey);

		if (myUI.showDialog()) {
			//Get values from dialog
			myKey.setElements(myUI.getSelectedElements());
			myKey.setKeyName(myUI.getKeyName());
			
			//Refresh tree
			_theFrame.getInfoTreeUI().refreshTree(curSelected); //Refresh view of key
			
			Object[] myCell = new Object[] {curEntity};
			_theFrame.getSketch().getGraphLayoutCache().hideCells(myCell, true);
			_theFrame.getSketch().getGraphLayoutCache().showCells(myCell, true);
			_theFrame.getSketch().repaint();
			
			_theFrame.getSketch().setDirty();
			_theFrame.getSketch().setSynced(false);
		}
	}
}
