package easik.view;

import java.awt.Color;
import java.awt.Font;
import javax.swing.BorderFactory;

import org.jgraph.graph.*;

import easik.Easik;
import easik.graph.EasikGraphModel;
import easik.view.*;
import easik.view.vertex.*;

public class ViewGraphModel extends EasikGraphModel {

	// The View this model is for
	private View _view;

	/**
	 * Constructs a new SketchGraphModel, which overrides cell attributes to
	 * display things appropriately for Easik.
	 */
	public ViewGraphModel(View inView) {
		super();
		_view = inView;
	}

	/**
	 * Overridden method to get cell attributes; we make sure the appropriate attributes
	 * are applied to the Easik objects before returning them.
	 *
	 * @see DefaultGraphModel.getAttributes(Object)
	 */
	public AttributeMap getAttributes(Object o) {
		if (o instanceof GraphCell) {
			GraphCell cell = (GraphCell) o;
			AttributeMap attribs = cell.getAttributes();
			AttributeMap easikAttribs = null;

			if (cell instanceof QueryNode) {
				easikAttribs = vertexAttributes();
			}

			if (easikAttribs != null) {
				if (_view.isCellSelected(cell)) {
					Color selColor = getColor("selection");
					float lineWidth = getWidth("selection", 3);

					GraphConstants.setBorder(easikAttribs,
							BorderFactory.createLineBorder(selColor, getIntWidth("view_query_border", 1)));
					GraphConstants.setForeground(easikAttribs, selColor);
					GraphConstants.setLineColor(easikAttribs, selColor);
					GraphConstants.setLineWidth(easikAttribs, lineWidth);
				}

				if (attribs == null) {
					cell.setAttributes(easikAttribs);
					attribs = easikAttribs;
				}
				else {
					attribs.applyMap(easikAttribs);
				}

				return attribs;
			}
		}

		return super.getAttributes(o);
	}

	/**
	 * Returns the attribute map for vertices (i.e. EntityNodes).
	 *
	 * @return a map of attributes to be used for new vertices
	 */
	private static AttributeMap vertexAttributes() {
		AttributeMap map = new AttributeMap();
		GraphConstants.setAutoSize(map, true);
		GraphConstants.setInset(map, 5);
		GraphConstants.setBorder(map,
			BorderFactory.createLineBorder(
				getColor("view_query_border"),
				getIntWidth("view_query_border", 1)
			)
		);
		GraphConstants.setBackground(map, getColor("view_query_bg"));
		GraphConstants.setForeground(map, getColor("view_query_fg"));
		GraphConstants.setFont(map,	GraphConstants.DEFAULTFONT.deriveFont(Font.BOLD, 12));
		GraphConstants.setOpaque(map, true);
		return map;
	}

	public void clearSelection() {
		_view.clearSelection();
	}

	public void setDirty() {
		_view.setDirty();
	}
}
