package easik.view.vertex;

import java.util.Set;

import javax.swing.tree.DefaultMutableTreeNode;

import easik.database.types.*;
import easik.view.View;
import easik.sketch.constraint.*;


/**
 * An entity node represents a table in a database. It has a name,
 * attributes, and unique keys. This class keeps track of all these
 * elements. 
 * 
 * @author Rob Fletcher 2005
 * @author Kevin Green 2006
 * @version 2006-06-21 Kevin Green
 */
public class QueryNode extends ViewVertex {
	/** Node representing this entity for the information tree */
	private DefaultMutableTreeNode _treeNode;

	/** The query this node represents */
	private String _query;

	/**
	 * Creates a new query node with the name provided.
	 * 
	 * @param nodeName The name of the new node
	 * @param inFrame The frame containing this node
	 * @param query The query represented by this node
	 */
	public QueryNode(String nodeName, View inView, String inQuery) {
		super(inView);
		_name = nodeName;
		_query = inQuery;
	}
	
	/**
	 * Creates a new enity node with the name provided.
	 * Stores visual representation information.
	 * 
	 * @param nodeName Name of the new node
	 * @param x X Coordinate of the new node
	 * @param y Y Coordinate of the new node
	 * @param inFrame The frame in which this node exists
	 * @param inQuery The query represented by this node
	 */
	public QueryNode(String nodeName, int x, int y, View inView, String inQuery ) {
		super(nodeName, x, y, inView);
		_query = inQuery;
		_treeNode = new DefaultMutableTreeNode(this);
	}

	/**
	 * Sets the query represented by this node. Note: There is no SQL syntax checking that takes place.
	 */
	public void setQuery(String inQuery){
		_query = inQuery;
	}

	/**
	 * Gets the query represented by this node.
	 */
	public String getQuery(){
		return _query;
	}

	/**
	 * Changes the name of the QueryNode.  This also updates the name in the
	 * QueryNode's ViewFrame, to maintain consistency.  Note that if you
	 * attempt to rename an QueryNode to one that already exists in the same
	 * frame, a trailing number will be added to make the name unique.  This
	 * means, however, that the name might not end up being what you set--if
	 * that's a problem, make sure the new name isn't taken yet yourself, via
	 * ViewFrame.getEntity().
	 *
	 * @see easik.ui.ViewFrame.getEntity(String)
	 * @param newName the new name to attempt to set.  The actual name set may
	 * 				  have a trailing number appended/incremented.
	 */
	public void setName(String newName) {
		String oldName = getName();
		// The name might have to change, if there are duplicates.  nodeRenamed tells us the final name to use:
		newName = _view.nodeRenamed(this, oldName, newName);
		super.setName(newName);
	}

	/**
	 * Sets the tree node used to display entity
	 * 
	 * @param inNode The tree node used to display entity
	 */
	public void setNode(DefaultMutableTreeNode inNode){
		_treeNode = inNode;
	}
	
	/**
	 * Returns the tree node used to display entity
	 * 
	 * @return The tree node used to display entity
	 */
	public DefaultMutableTreeNode getNode(){
		return _treeNode;
	}
}
