<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet
  version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exslt="http://exslt.org/common"
  xmlns:msxsl="urn:schemas-microsoft-com:xslt"
  xmlns="http://www.w3.org/1999/xhtml"
  exclude-result-prefixes="exslt msxsl">
  <xsl:output method="html" encoding="iso8859-1" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" indent="yes"/>

  <xsl:variable name="page-translate"/>

  <!-- If set, <a href="whatever.xml"> will be converted to <a href="whatever.html">: -->
  <xsl:param name="xml-to-html"/>

  <!-- Hack for IE to support exslt:node-set(...) -->
  <msxsl:script language="JScript" implements-prefix="exslt">
	this['node-set'] =  function (x) {
	  return x;
	}
  </msxsl:script>

  <!-- The title prefix that we add before the individual page title: -->
  <xsl:variable name="site-title">Easik</xsl:variable>

  <!--
  Various possibilities for the character(s) between the title, above, and the individual page title:
  <xsl:variable name="title-joiner"> → </xsl:variable>
  <xsl:variable name="title-joiner"> » </xsl:variable>
  <xsl:variable name="title-joiner"> — </xsl:variable>
  <xsl:variable name="title-joiner">&#xa0;</xsl:variable>
  <xsl:variable name="title-joiner">&#x2009;</xsl:variable>

  U+2006 is a 1/6 em space (narrower than a normal space), but unfortunately doesn't appear to work in Windows
  <xsl:variable name="title-joiner">&#x2006;»&#x2006;</xsl:variable>
  -->
  <xsl:variable name="title-joiner"> » </xsl:variable>

  <xsl:template name="common-head">
	<xsl:param name="title"/>
	<head>
	  <xsl:if test="$title and count(exslt:node-set($title)) > 0">
		<xsl:call-template name="title"><xsl:with-param name="title" select="$title"/></xsl:call-template>
	  </xsl:if>
	  <link href="../style/easik.css" rel="stylesheet" type="text/css"/>
	  <!--
	  Copy-and-paste me to include a javascript file:
	  <script type="text/javascript" src="..../somescript.js"/>
	  -->
	</head>
  </xsl:template>

  <!--
  Produces the <title>...</title> tag.  The first element of this is always {site-title}, followed by
  the *text* of any passed-in elements.  Typically something like:
  <xsl:call-template name="title"><xsl:with-param name="title">Elem 1<z/>Elem 2<z/>...</xsl:with-param></xsl:call-template>
  Note that the <z/> is ignored: it is there simply to provide separation between node items
  -->
  <xsl:template name="title">
	<xsl:param name="title"/>
	<title>
	  <xsl:value-of select="$site-title"
	  /><xsl:for-each select="exslt:node-set($title)/node()"
		><xsl:value-of select="$title-joiner"
		/><xsl:value-of select="string()"
	  /></xsl:for-each>
	</title>
  </xsl:template>

  <!--
  This is used to clone HTML nodes, but also brings them into the xhtml namespace.
  
  If a page-translate variable is set, we change <a href="whatever.xml"></a> to <a href="#whatever_xml"></a>,
  and change <a href="whatever.xml#blah"></a> to just <a href="#blah"></a>.
  
  Otherwise, if the xml-to-html parameter is set, we look for <a href="whatever.xml"></a>
  tags and convert them to <a href="whatever.html"></a>.

  We also recognize <title/> and change it to whatever the site-title variable,
  above, is set to.

  We similarly recognize constructs such as:
	<list type="ul">
	  <item title="Abc" comment="test comment">
		Some text here
	  </item>
	  <item title="Def"/>
	</list>
	And translate them into a ul, ol, or dl tag, bolding the title, putting the comment
	in parentheses (if present), and adding a colon after the title (and comment), but
	only when there is text.
  -->
  <xsl:template mode="html" match="@*|node()">
	<xsl:choose>
	  <xsl:when test="local-name() = 'title'">
		<xsl:value-of select="$site-title"/>
	  </xsl:when>
	  <xsl:when test="local-name() = 'list' and (@type = 'ol' or @type = 'ul')">
		<xsl:element name="{@type}">
		  <xsl:apply-templates mode="html" select="@*[not(local-name() = 'type')]|item|li|list|ul|ol"/>
		</xsl:element>
	  </xsl:when>
	  <xsl:when test="local-name() = 'item' and local-name(..) = 'list'">
		<li>
		  <xsl:apply-templates mode="html" select="@*[not(local-name() = 'title' or local-name() = 'comment')]"/>
		  <p>
			<xsl:if test="@id"><a name="{@id}"/></xsl:if>
			<xsl:call-template name="list-item-title"/>
			<xsl:apply-templates mode="html" select="node()"/>
		  </p>
		</li>
	  </xsl:when>
	  <xsl:when test="self::*"><!-- An element -->
		<xsl:element name="{local-name()}">
		  <xsl:apply-templates mode="html" select="@*|node()"/>
		</xsl:element>
	  </xsl:when>
	  <xsl:when test="$page-translate and local-name(..) = 'a' and local-name() = 'href' and contains(., '.xml') and not(contains(., '/'))">
		<xsl:attribute name="href">
		  <xsl:choose>
			<xsl:when test="contains(., '#')">#<xsl:value-of select="substring-after(., '#')"/></xsl:when>
			<xsl:otherwise>#<xsl:value-of select="translate(., '.', '_')"/></xsl:otherwise>
		  </xsl:choose>
		</xsl:attribute>
	  </xsl:when>
	  <xsl:when test="$xml-to-html and local-name(..) = 'a' and local-name() = 'href' and contains(., '.xml') and not(contains(., '/'))">
		<!-- The href attribute of an 'a' tag, which links to localfilename.xml (or maybe local.xml#whatever): change it to .html -->
		<xsl:attribute name="href"><xsl:value-of select="concat(substring-before(., '.xml'), '.html', substring-after(., '.xml'))"/></xsl:attribute>
	  </xsl:when>
	  <xsl:otherwise>
		<xsl:copy/>
	  </xsl:otherwise>
	</xsl:choose>
  </xsl:template>

  <xsl:template name="list-item-title">
	<xsl:if test="@title">
	  <span class="list-item-title">
		<b><xsl:value-of select="@title"/></b>
		<xsl:if test="@comment"> (<xsl:value-of select="@comment"/>)</xsl:if>
		<xsl:if test="count(node()) > 0"><xsl:text>: </xsl:text></xsl:if>
	  </span>
	</xsl:if>
  </xsl:template>
</xsl:stylesheet>

<!-- vim:sw=2
-->
